@@ -26,7 +26,9 @@
 #endif
 
 #include "nv_include.h"
+#ifdef HAVE_XAA_H
 #include "xaalocal.h"
+#endif
 #include "miline.h"
 #include "nv_dma.h"
 
@@ -70,6 +72,7 @@ static const int NVCopyROP_PM[16] =
    0xFA             /* GXset */
 };
 
+#ifdef HAVE_XAA_H
 static const int NVPatternROP[16] =
 {
    0x00,
@@ -89,6 +92,7 @@ static const int NVPatternROP[16] =
    0x5F,
    0xFF
 };
+#endif
 
 void
 NVDmaKickoff(NVPtr pNv)
@@ -289,6 +293,7 @@ void NVSync(ScrnInfoPtr pScrn)
     while(pNv->PGRAPH[0x0700/4]);
 }
 
+#ifdef HAVE_XAA_H
 static void
 NVDMAKickoffCallback (ScrnInfoPtr pScrn)
 {
@@ -298,7 +303,6 @@ NVDMAKickoffCallback (ScrnInfoPtr pScrn)
    pNv->DMAKickoffCallback = NULL;
 }
 
-
 static void
 NVSetupForScreenToScreenCopy(
    ScrnInfoPtr pScrn, 
@@ -646,12 +650,14 @@ NVDisableClipping(ScrnInfoPtr pScrn)
     NVDmaNext (pNv, 0x7FFF7FFF);
 }
 
+#endif
 
 /* Initialize XAA acceleration info */
 Bool
 NVAccelInit(ScreenPtr pScreen) 
 {
-   ScrnInfoPtr pScrn = xf86Screens[pScreen->myNum];
+#ifdef HAVE_XAA_H
+   ScrnInfoPtr pScrn = xf86ScreenToScrn(pScreen);
    NVPtr pNv = NVPTR(pScrn);
    XAAInfoRecPtr accel;
 
@@ -710,4 +716,7 @@ NVAccelInit(ScreenPtr pScreen)
    miSetZeroLineBias(pScreen, OCTANT1 | OCTANT3 | OCTANT4 | OCTANT6);
 
    return (XAAInit(pScreen, accel));
+#else
+   return FALSE;
+#endif
 }
